==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/nl/Filter.js <==
({
	"clearFilterDialogTitle": "Filter wissen",
	"filterDefDialogTitle": "Filteren",
	"ruleTitleTemplate": "Regel ${0}",
	
	"conditionEqual": "gelijk aan",
	"conditionNotEqual": "niet gelijk aan",
	"conditionLess": "is kleiner dan",
	"conditionLessEqual": "kleiner dan of gelijk aan",
	"conditionLarger": "is groter dan",
	"conditionLargerEqual": "groter dan of gelijk aan",
	"conditionContains": "bevat",
	"conditionIs": "is",
	"conditionStartsWith": "begint met",
	"conditionEndWith": "eindigt op",
	"conditionNotContain": "bevat niet",
	"conditionIsNot": "is niet",
	"conditionNotStartWith": "begint niet met",
	"conditionNotEndWith": "eindigt niet op",
	"conditionBefore": "voor",
	"conditionAfter": "na",
	"conditionRange": "bereik",
	"conditionIsEmpty": "is leeg",
	
	"all": "alle",
	"any": "een of meer",
	"relationAll": "alle regels",
	"waiRelAll": "Voldoen aan al deze regels:",
	"relationAny": "een of meer regels",
	"waiRelAny": "Voldoen aan een van deze regels:",
	"relationMsgFront": "Voldoen aan",
	"relationMsgTail": "",
	"and": "en",
	"or": "of",
	
	"addRuleButton": "Regel toevoegen",
	"waiAddRuleButton": "Een nieuwe regel toevoegen",
	"removeRuleButton": "Regel verwijderen",
	"waiRemoveRuleButtonTemplate": "Regel ${0} verwijderen",
	
	"cancelButton": "Annuleren",
	"waiCancelButton": "Dit dialoogvenster annuleren",
	"clearButton": "Leegmaken",
	"waiClearButton": "Het filter wissen",
	"filterButton": "Filteren",
	"waiFilterButton": "Het filter verzenden",
	
	"columnSelectLabel": "Kolom",
	"waiColumnSelectTemplate": "Kolom voor regel ${0}",
	"conditionSelectLabel": "Voorwaarde",
	"waiConditionSelectTemplate": "Voorwaarde voor regel ${0}",
	"valueBoxLabel": "Waarde",
	"waiValueBoxTemplate": "Geef een filterwaarde op voor regel ${0}",
	
	"rangeTo": "tot",
	"rangeTemplate": "van ${0} tot ${1}",
	
	"statusTipHeaderColumn": "Kolom",
	"statusTipHeaderCondition": "Regels",
	"statusTipTitle": "Filterbalk",
	"statusTipMsg": "Klik hier op de filterbalk om te filteren op waarden in ${0}.",
	"anycolumn": "een kolom",
	"statusTipTitleNoFilter": "Filterbalk",
	"statusTipTitleHasFilter": "Filter",
	"statusTipRelPre": "Voldoen aan",
	"statusTipRelPost": "regel.",
	
	"defaultItemsName": "items",
	"filterBarMsgHasFilterTemplate": "${0} van ${1} ${2} afgebeeld.",
	"filterBarMsgNoFilterTemplate": "Geen filter toegepast",
	
	"filterBarDefButton": "Filter definiëren",
	"waiFilterBarDefButton": "De tabel filteren",
	"a11yFilterBarDefButton": "Filteren...",
	"filterBarClearButton": "Filter wissen",
	"waiFilterBarClearButton": "Het filter wissen",
	"closeFilterBarBtn": "Filterbalk sluiten",
	
	"clearFilterMsg": "Hiermee verwijdert u het filter en worden alle beschikbare records afgebeeld.",
	"anyColumnOption": "Een kolom",
	
	"trueLabel": "Waar",
	"falseLabel": "Onwaar"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/nl/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "Filter wissen",
	"filterDefDialogTitle": "Filteren",
	"ruleTitleTemplate": "Regel ${0}",
	
	"conditionEqual": "gelijk aan",
	"conditionNotEqual": "niet gelijk aan",
	"conditionLess": "is kleiner dan",
	"conditionLessEqual": "kleiner dan of gelijk aan",
	"conditionLarger": "is groter dan",
	"conditionLargerEqual": "groter dan of gelijk aan",
	"conditionContains": "bevat",
	"conditionIs": "is",
	"conditionStartsWith": "begint met",
	"conditionEndWith": "eindigt op",
	"conditionNotContain": "bevat niet",
	"conditionIsNot": "is niet",
	"conditionNotStartWith": "begint niet met",
	"conditionNotEndWith": "eindigt niet op",
	"conditionBefore": "voor",
	"conditionAfter": "na",
	"conditionRange": "bereik",
	"conditionIsEmpty": "is leeg",
	
	"all": "alle",
	"any": "een of meer",
	"relationAll": "alle regels",
	"waiRelAll": "Voldoen aan al deze regels:",
	"relationAny": "een of meer regels",
	"waiRelAny": "Voldoen aan een van deze regels:",
	"relationMsgFront": "Voldoen aan",
	"relationMsgTail": "",
	"and": "en",
	"or": "of",
	
	"addRuleButton": "Regel toevoegen",
	"waiAddRuleButton": "Een nieuwe regel toevoegen",
	"removeRuleButton": "Regel verwijderen",
	"waiRemoveRuleButtonTemplate": "Regel ${0} verwijderen",
	
	"cancelButton": "Annuleren",
	"waiCancelButton": "Dit dialoogvenster annuleren",
	"clearButton": "Leegmaken",
	"waiClearButton": "Het filter wissen",
	"filterButton": "Filteren",
	"waiFilterButton": "Het filter verzenden",
	
	"columnSelectLabel": "Kolom",
	"waiColumnSelectTemplate": "Kolom voor regel ${0}",
	"conditionSelectLabel": "Voorwaarde",
	"waiConditionSelectTemplate": "Voorwaarde voor regel ${0}",
	"valueBoxLabel": "Waarde",
	"waiValueBoxTemplate": "Geef een filterwaarde op voor regel ${0}",
	
	"rangeTo": "tot",
	"rangeTemplate": "van ${0} tot ${1}",
	
	"statusTipHeaderColumn": "Kolom",
	"statusTipHeaderCondition": "Regels",
	"statusTipTitle": "Filterbalk",
	"statusTipMsg": "Klik hier op de filterbalk om te filteren op waarden in ${0}.",
	"anycolumn": "een kolom",
	"statusTipTitleNoFilter": "Filterbalk",
	"statusTipTitleHasFilter": "Filter",
	"statusTipRelAny": "Voldoen aan een van de regels.",
	"statusTipRelAll": "Voldoen aan alle regels.",
	
	"defaultItemsName": "items",
	"filterBarMsgHasFilterTemplate": "${0} van ${1} ${2} afgebeeld.",
	"filterBarMsgNoFilterTemplate": "Geen filter toegepast",
	
	"filterBarDefButton": "Filter definiëren",
	"waiFilterBarDefButton": "De tabel filteren",
	"a11yFilterBarDefButton": "Filteren...",
	"filterBarClearButton": "Filter wissen",
	"waiFilterBarClearButton": "Het filter wissen",
	"closeFilterBarBtn": "Filterbalk sluiten",
	
	"clearFilterMsg": "Hiermee verwijdert u het filter en worden alle beschikbare records afgebeeld.",
	"anyColumnOption": "Een kolom",
	
	"trueLabel": "Waar",
	"falseLabel": "Onwaar"
})
//end v1.x content
);
